==> exo.jcr.framework.command-1.9.3.1-sources.jar: org/exoplatform/frameworks/jcr/cli/GetNodesCommand.java <==
/*
 * Copyright (C) 2003-2007 eXo Platform SAS.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Affero General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see<http://www.gnu.org/licenses/>.
 */
package org.exoplatform.frameworks.jcr.cli;

import javax.jcr.Node;
import javax.jcr.NodeIterator;
import javax.jcr.Property;
import javax.jcr.PropertyIterator;

/**
 * Created by The eXo Platform SAS
 * 
 * @author Vitaliy Obmanjuk
 * @version $Id: $
 */

public class GetNodesCommand extends AbstractCliCommand {

  @Override
  public boolean perform(CliAppContext ctx) {
    String output = "";
    try {
      if (ctx.getCurrentItem().isNode()) {
        Node currentNode = (Node) ctx.getCurrentItem();
        PropertyIterator propertyIterator = currentNode.getProperties();
        output += "Properties list for " + currentNode.getPath() + ":\n";
        while (propertyIterator.hasNext()) {
          Property property = propertyIterator.nextProperty();
          output += property.getName() + "\n";
        }
        NodeIterator nodeIterator = currentNode.getNodes();
        output += "Nodes list for " + currentNode.getPath() + ":\n";
        while (nodeIterator.hasNext()) {
          Node node = nodeIterator.nextNode();
          output += node.getPath() + "\n";
        }
      } else {
        output += "Current item is property: "
            + ((Property) ctx.getCurrentItem()).getName() + "\n";
      }
    } catch (Exception e) {
      output = "Can't execute command - " + e.getMessage() + "\n";
    }
    ctx.setOutput(output);
    return false;
  }
}

==> exo.jcr.framework.command-1.10.2-sources.jar: org/exoplatform/frameworks/jcr/cli/GetNodesCommand.java <==
/*
 * Copyright (C) 2003-2007 eXo Platform SAS.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Affero General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see<http://www.gnu.org/licenses/>.
 */
package org.exoplatform.frameworks.jcr.cli;

import javax.jcr.Node;
import javax.jcr.NodeIterator;
import javax.jcr.Property;
import javax.jcr.PropertyIterator;

/**
 * Created by The eXo Platform SAS
 * 
 * @author Vitaliy Obmanjuk
 * @version $Id: $
 */

public class GetNodesCommand extends AbstractCliCommand {

  @Override
  public boolean perform(CliAppContext ctx) {
    String output = "";
    try {
      if (ctx.getCurrentItem().isNode()) {
        Node currentNode = (Node) ctx.getCurrentItem();
        PropertyIterator propertyIterator = currentNode.getProperties();
        output += "Properties list for " + currentNode.getPath() + ":\n";
        while (propertyIterator.hasNext()) {
          Property property = propertyIterator.nextProperty();
          output += property.getName() + "\n";
        }
        NodeIterator nodeIterator = currentNode.getNodes();
        output += "Nodes list for " + currentNode.getPath() + ":\n";
        while (nodeIterator.hasNext()) {
          Node node = nodeIterator.nextNode();
          output += node.getPath() + "\n";
        }
      } else {
        output += "Current item is property: " + ((Property) ctx.getCurrentItem()).getName() + "\n";
      }
    } catch (Exception e) {
      output = "Can't execute command - " + e.getMessage() + "\n";
    }
    ctx.setOutput(output);
    return false;
  }
}
